Module try_from

Module try_from 

Enums

FromValueError
Error type for Value extraction failures

Traits

TryFromValue
Trait for strict extraction of Rust types from Value.
TryFromValueCoerce
Trait for widening extraction of Rust types from Value.