Module try_from
reifydb_
type
0.3.0
Module try_
from
Module Items
Enums
Traits
In reifydb_
type::
value
reifydb_type
::
value
Module
try_
from
Enums

From
Value
Error
Error type for Value extraction failures
Traits

TryFrom
Value
Trait for strict extraction of Rust types from Value.
TryFrom
Value
Coerce
Trait for widening extraction of Rust types from Value.